# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base_msgs.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='base_msgs.proto',
  package='AssisiMsg',
  serialized_pb='\n\x0f\x62\x61se_msgs.proto\x12\tAssisiMsg\"!\n\x04Time\x12\x0b\n\x03sec\x18\x01 \x02(\x04\x12\x0c\n\x04nsec\x18\x02 \x02(\x04\"F\n\x06Header\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1e\n\x05stamp\x18\x02 \x01(\x0b\x32\x0f.AssisiMsg.Time\x12\x10\n\x08\x66rame_id\x18\x03 \x01(\t\"+\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\"-\n\x07Vector3\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x0c\n\x01z\x18\x03 \x02(\x01:\x01\x30\"A\n\nQuaternion\x12\x0c\n\x01x\x18\x01 \x01(\x01:\x01\x30\x12\x0c\n\x01y\x18\x02 \x01(\x01:\x01\x30\x12\t\n\x01z\x18\x03 \x02(\x01\x12\x0c\n\x01w\x18\x04 \x01(\x01:\x01\x31\"V\n\x04Pose\x12\"\n\x08position\x18\x01 \x02(\x0b\x32\x10.AssisiMsg.Point\x12*\n\x0borientation\x18\x02 \x02(\x0b\x32\x15.AssisiMsg.Quaternion\"O\n\x0bPoseStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1d\n\x04pose\x18\x02 \x02(\x0b\x32\x0f.AssisiMsg.Pose\"P\n\x05Twist\x12\"\n\x06linear\x18\x01 \x02(\x0b\x32\x12.AssisiMsg.Vector3\x12#\n\x07\x61ngular\x18\x02 \x02(\x0b\x32\x12.AssisiMsg.Vector3\"R\n\x0cTwistStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1f\n\x05twist\x18\x02 \x02(\x0b\x32\x10.AssisiMsg.Twist\"@\n\x05\x43olor\x12\x0b\n\x03red\x18\x01 \x02(\x01\x12\r\n\x05green\x18\x02 \x02(\x01\x12\x0c\n\x04\x62lue\x18\x03 \x02(\x01\x12\r\n\x05\x61lpha\x18\x04 \x01(\x01\"R\n\x0c\x43olorStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12\x1f\n\x05\x63olor\x18\x02 \x02(\x0b\x32\x10.AssisiMsg.Color\"R\n\x07Polygon\x12\"\n\x08vertices\x18\x01 \x03(\x0b\x32\x10.AssisiMsg.Point\x12\x11\n\x06height\x18\x02 \x01(\x01:\x01\x31\x12\x10\n\x04mass\x18\x03 \x01(\x01:\x02-1\"X\n\x0ePolygonStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12#\n\x07polygon\x18\x02 \x02(\x0b\x32\x12.AssisiMsg.Polygon\">\n\x08\x43ylinder\x12\x0e\n\x06radius\x18\x01 \x02(\x01\x12\x11\n\x06height\x18\x02 \x01(\x01:\x01\x31\x12\x0f\n\x04mass\x18\x03 \x01(\x01:\x01\x31\"[\n\x0f\x43ylinderStamped\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.AssisiMsg.Header\x12%\n\x08\x63ylinder\x18\x02 \x02(\x0b\x32\x13.AssisiMsg.Cylinder')




_TIME = _descriptor.Descriptor(
  name='Time',
  full_name='AssisiMsg.Time',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='AssisiMsg.Time.sec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nsec', full_name='AssisiMsg.Time.nsec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=30,
  serialized_end=63,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='AssisiMsg.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='AssisiMsg.Header.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='AssisiMsg.Header.stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='AssisiMsg.Header.frame_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=65,
  serialized_end=135,
)


_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='AssisiMsg.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='AssisiMsg.Point.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='AssisiMsg.Point.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='AssisiMsg.Point.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=137,
  serialized_end=180,
)


_VECTOR3 = _descriptor.Descriptor(
  name='Vector3',
  full_name='AssisiMsg.Vector3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='AssisiMsg.Vector3.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='AssisiMsg.Vector3.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='AssisiMsg.Vector3.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=182,
  serialized_end=227,
)


_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='AssisiMsg.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='AssisiMsg.Quaternion.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='AssisiMsg.Quaternion.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='AssisiMsg.Quaternion.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w', full_name='AssisiMsg.Quaternion.w', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=229,
  serialized_end=294,
)


_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='AssisiMsg.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='AssisiMsg.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='AssisiMsg.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=296,
  serialized_end=382,
)


_POSESTAMPED = _descriptor.Descriptor(
  name='PoseStamped',
  full_name='AssisiMsg.PoseStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.PoseStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='AssisiMsg.PoseStamped.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=384,
  serialized_end=463,
)


_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='AssisiMsg.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='AssisiMsg.Twist.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='AssisiMsg.Twist.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=465,
  serialized_end=545,
)


_TWISTSTAMPED = _descriptor.Descriptor(
  name='TwistStamped',
  full_name='AssisiMsg.TwistStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.TwistStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='twist', full_name='AssisiMsg.TwistStamped.twist', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=547,
  serialized_end=629,
)


_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='AssisiMsg.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='red', full_name='AssisiMsg.Color.red', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='green', full_name='AssisiMsg.Color.green', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blue', full_name='AssisiMsg.Color.blue', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alpha', full_name='AssisiMsg.Color.alpha', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=631,
  serialized_end=695,
)


_COLORSTAMPED = _descriptor.Descriptor(
  name='ColorStamped',
  full_name='AssisiMsg.ColorStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.ColorStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='AssisiMsg.ColorStamped.color', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=697,
  serialized_end=779,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='AssisiMsg.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='AssisiMsg.Polygon.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='AssisiMsg.Polygon.height', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass', full_name='AssisiMsg.Polygon.mass', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=781,
  serialized_end=863,
)


_POLYGONSTAMPED = _descriptor.Descriptor(
  name='PolygonStamped',
  full_name='AssisiMsg.PolygonStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.PolygonStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='AssisiMsg.PolygonStamped.polygon', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=865,
  serialized_end=953,
)


_CYLINDER = _descriptor.Descriptor(
  name='Cylinder',
  full_name='AssisiMsg.Cylinder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='radius', full_name='AssisiMsg.Cylinder.radius', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='AssisiMsg.Cylinder.height', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mass', full_name='AssisiMsg.Cylinder.mass', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=955,
  serialized_end=1017,
)


_CYLINDERSTAMPED = _descriptor.Descriptor(
  name='CylinderStamped',
  full_name='AssisiMsg.CylinderStamped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='AssisiMsg.CylinderStamped.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cylinder', full_name='AssisiMsg.CylinderStamped.cylinder', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1019,
  serialized_end=1110,
)

_HEADER.fields_by_name['stamp'].message_type = _TIME
_POSE.fields_by_name['position'].message_type = _POINT
_POSE.fields_by_name['orientation'].message_type = _QUATERNION
_POSESTAMPED.fields_by_name['header'].message_type = _HEADER
_POSESTAMPED.fields_by_name['pose'].message_type = _POSE
_TWIST.fields_by_name['linear'].message_type = _VECTOR3
_TWIST.fields_by_name['angular'].message_type = _VECTOR3
_TWISTSTAMPED.fields_by_name['header'].message_type = _HEADER
_TWISTSTAMPED.fields_by_name['twist'].message_type = _TWIST
_COLORSTAMPED.fields_by_name['header'].message_type = _HEADER
_COLORSTAMPED.fields_by_name['color'].message_type = _COLOR
_POLYGON.fields_by_name['vertices'].message_type = _POINT
_POLYGONSTAMPED.fields_by_name['header'].message_type = _HEADER
_POLYGONSTAMPED.fields_by_name['polygon'].message_type = _POLYGON
_CYLINDERSTAMPED.fields_by_name['header'].message_type = _HEADER
_CYLINDERSTAMPED.fields_by_name['cylinder'].message_type = _CYLINDER
DESCRIPTOR.message_types_by_name['Time'] = _TIME
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['Vector3'] = _VECTOR3
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
DESCRIPTOR.message_types_by_name['PoseStamped'] = _POSESTAMPED
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST
DESCRIPTOR.message_types_by_name['TwistStamped'] = _TWISTSTAMPED
DESCRIPTOR.message_types_by_name['Color'] = _COLOR
DESCRIPTOR.message_types_by_name['ColorStamped'] = _COLORSTAMPED
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['PolygonStamped'] = _POLYGONSTAMPED
DESCRIPTOR.message_types_by_name['Cylinder'] = _CYLINDER
DESCRIPTOR.message_types_by_name['CylinderStamped'] = _CYLINDERSTAMPED

class Time(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TIME

  # @@protoc_insertion_point(class_scope:AssisiMsg.Time)

class Header(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _HEADER

  # @@protoc_insertion_point(class_scope:AssisiMsg.Header)

class Point(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POINT

  # @@protoc_insertion_point(class_scope:AssisiMsg.Point)

class Vector3(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VECTOR3

  # @@protoc_insertion_point(class_scope:AssisiMsg.Vector3)

class Quaternion(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _QUATERNION

  # @@protoc_insertion_point(class_scope:AssisiMsg.Quaternion)

class Pose(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSE

  # @@protoc_insertion_point(class_scope:AssisiMsg.Pose)

class PoseStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSESTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.PoseStamped)

class Twist(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TWIST

  # @@protoc_insertion_point(class_scope:AssisiMsg.Twist)

class TwistStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TWISTSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.TwistStamped)

class Color(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COLOR

  # @@protoc_insertion_point(class_scope:AssisiMsg.Color)

class ColorStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COLORSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.ColorStamped)

class Polygon(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POLYGON

  # @@protoc_insertion_point(class_scope:AssisiMsg.Polygon)

class PolygonStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POLYGONSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.PolygonStamped)

class Cylinder(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDER

  # @@protoc_insertion_point(class_scope:AssisiMsg.Cylinder)

class CylinderStamped(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDERSTAMPED

  # @@protoc_insertion_point(class_scope:AssisiMsg.CylinderStamped)


# @@protoc_insertion_point(module_scope)
