""" 
The assisipy Python package implements the API for monitoring and controlling CASU devices.
It works both with simulated CASUS and pyhsical devices. It also provides several utility
classes for interacting with the simulation engine.
"""

__version__ = '0.13.0'

